import httpRequest from '@/utils/axios'
import type { ChannelRequestParams, ChannelListSearch } from './types'

// 获取渠道列表
export function getChannelList(params?: ChannelListSearch) {
  return httpRequest.get('/api/zws/v1/backend/channel/list', { params })
}

// 获取渠道详情
export function getChannelDetail(params?: { id?: string | string[] }) {
  return httpRequest.get('/api/zws/v1/backend/channel/view', { params })
}

// 获取成员列表
export function getChannelUserList(params?: { id?: string | string[] }) {
  return httpRequest.get('/api/zws/v1/backend/channel/member', { params })
}

// 新增渠道成员
export function addMember(data: { user_id: string; channels_id: string; roles: string; type?: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/member-create', data)
}

// 删除成员
export function deleteMember(data: { user_id: string; channel_id: string; role_id: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/member-delete', data)
}

// 获取渠道相关的公共map
export function getChannelMap() {
  return httpRequest.get('/api/zws/v1/backend/channel/conditions')
}

// 搜索用户
export function searchUser(params: { q: string }) {
  return httpRequest.get('/api/zws/v1/backend/common/search-user', { params })
}

// 获取渠道角色
export function getRoles() {
  return httpRequest.get('/api/zws/v1/backend/common/channel-roles')
}

// 创建渠道
export function createChannel(data: ChannelRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/channel/create', data)
}

// 更新渠道
export function updateChannel(data: { id: string } & ChannelRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/channel/update', data)
}
